@@ -90,6 +90,24 @@ ch_flash_error_dialog (ChFlashPrivate *priv, const gchar *title, const gchar *me
 	gtk_widget_destroy (widget);
 }
 
+/**
+ * ch_flash_help_button_cb:
+ **/
+static void
+ch_flash_help_button_cb (GtkWidget *widget, ChFlashPrivate *priv)
+{
+	gboolean ret;
+	GError *error = NULL;
+	ret = gtk_show_uri (NULL,
+			    "help:colorhug-client/update-firmware",
+			    GDK_CURRENT_TIME,
+			    &error);
+	if (!ret) {
+		g_warning ("Failed to load help document: %s", error->message);
+		g_error_free (error);
+	}
+}
+
 /**
  * ch_flash_error_do_not_panic:
  **/
@@ -246,7 +264,7 @@ ch_flash_set_flash_success_1 (ChFlashPrivate *priv)
 	/* update UI */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_status"));
 	/* TRANSLATORS: tell the hardware we succeeded */
-	title = _("Setting flash success...");
+	title = _("Completing firmware upgrade…");
 	gtk_label_set_label (GTK_LABEL (widget), title);
 
 	/* need to boot into bootloader */
@@ -355,7 +373,7 @@ ch_flash_verify_firmware_cb (GObject *source,
 	gtk_widget_hide (widget);
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_msg"));
 	/* TRANSLATORS: boot into the new firmware */
-	title = _("Starting the new firmware...");
+	title = _("Starting the new firmware…");
 	gtk_label_set_label (GTK_LABEL (widget), title);
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "box_detected"));
 	gtk_widget_show (widget);
@@ -408,7 +426,7 @@ ch_flash_write_firmware_cb (GObject *source,
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_status"));
 	/* TRANSLATORS: now we've written the firmware, we have to
 	 * verify it before we tell the device it was successfull */
-	title = _("Verifying new firmware...");
+	title = _("Verifying new firmware…");
 	gtk_label_set_label (GTK_LABEL (widget), title);
 
 	/* verify firmware */
@@ -437,7 +455,7 @@ ch_flash_set_flash_success_0 (ChFlashPrivate *priv)
 	/* update UI */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_status"));
 	/* TRANSLATORS: now write the new firmware chunks */
-	title = _("Writing new firmware...");
+	title = _("Writing new firmware…");
 	gtk_label_set_label (GTK_LABEL (widget), title);
 
 	/* write firmware */
@@ -529,7 +547,7 @@ ch_flash_got_firmware_data (ChFlashPrivate *priv)
 	/* update UI */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_status"));
 	/* TRANSLATORS: switch from firmware mode into bootloader mode */
-	title = _("Resetting into bootloader...");
+	title = _("Starting firmware upgrade…");
 	gtk_label_set_label (GTK_LABEL (widget), title);
 
 	/* this is planned */
@@ -690,6 +708,30 @@ ch_flash_show_warning_dialog (ChFlashPrivate *priv)
 	return (response == GTK_RESPONSE_OK);
 }
 
+/**
+ * ch_flash_get_device_download_kind:
+ **/
+static const gchar *
+ch_flash_get_device_download_kind (ChFlashPrivate *priv)
+{
+	const char *str = NULL;
+	switch (ch_device_get_mode (priv->device)) {
+	case CH_DEVICE_MODE_LEGACY:
+	case CH_DEVICE_MODE_BOOTLOADER:
+	case CH_DEVICE_MODE_FIRMWARE:
+		str = "colorhug";
+		break;
+	case CH_DEVICE_MODE_BOOTLOADER_SPECTRO:
+	case CH_DEVICE_MODE_FIRMWARE_SPECTRO:
+		str = "colorhug-spectro";
+		break;
+	default:
+		str = "unknown";
+		break;
+	}
+	return str;
+}
+
 /**
  * ch_flash_flash_button_cb:
  **/
@@ -726,7 +768,7 @@ ch_flash_flash_button_cb (GtkWidget *widget, ChFlashPrivate *priv)
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_status"));
 	/* TRANSLATORS: downloading the firmware binary file from a
 	 * remote server */
-	title = _("Downloading update...");
+	title = _("Downloading update…");
 	gtk_label_set_label (GTK_LABEL (widget), title);
 
 	/* set progressbar to zero */
@@ -734,8 +776,10 @@ ch_flash_flash_button_cb (GtkWidget *widget, ChFlashPrivate *priv)
 	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (widget), 0.0f);
 
 	/* download file */
-	server_uri = g_settings_get_string (priv->settings, "firmware-uri");
+	server_uri = g_settings_get_string (priv->settings, "server-uri");
 	uri = g_build_filename (server_uri,
+				ch_flash_get_device_download_kind (priv),
+				"firmware",
 				priv->filename,
 				NULL);
 	g_debug ("Downloading %s", uri);
@@ -989,6 +1033,10 @@ ch_flash_got_device_data (ChFlashPrivate *priv)
 		/* TRANSLATORS: first release hardware */
 		str = g_strdup (_("ColorHug Detected"));
 		break;
+	case 0x02:
+		/* TRANSLATORS: first release hardware */
+		str = g_strdup (_("ColorHug Spectro Detected"));
+		break;
 	case 0xff:
 		/* TRANSLATORS: fake hardware */
 		str = g_strdup (_("Emulated ColorHug Detected"));
@@ -1033,7 +1081,7 @@ ch_flash_got_device_data (ChFlashPrivate *priv)
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_msg"));
 	/* TRANSLATORS: Check for newer version of the firmware compared
 	 * to what is installed on the device */
-	title = _("Checking for updates...");
+	title = _("Checking for updates…");
 	gtk_label_set_label (GTK_LABEL (widget), title);
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "spinner_progress"));
 	gtk_widget_show (widget);
@@ -1041,7 +1089,7 @@ ch_flash_got_device_data (ChFlashPrivate *priv)
 	/* we've manually specified a local firmware file */
 	if (priv->filename != NULL) {
 		/* TRANSLATORS: we've specified a local file */
-		title = _("Flashing firmware file...");
+		title = _("Flashing firmware file…");
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_msg"));
 		gtk_label_set_label (GTK_LABEL (widget), title);
 		ret = g_file_get_contents (priv->filename,
@@ -1061,8 +1109,10 @@ ch_flash_got_device_data (ChFlashPrivate *priv)
 	}
 
 	/* get the latest manifest file */
-	server_uri = g_settings_get_string (priv->settings, "firmware-uri");
+	server_uri = g_settings_get_string (priv->settings, "server-uri");
 	uri = g_build_filename (server_uri,
+				ch_flash_get_device_download_kind (priv),
+				"firmware",
 				"metadata.xml",
 				NULL);
 	base_uri = soup_uri_new (uri);
@@ -1216,7 +1266,7 @@ fake_device:
 		gtk_widget_show (widget);
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_msg"));
 		/* TRANSLATORS: request the firmware version from the device */
-		title = _("Getting firmware version...");
+		title = _("Getting firmware version…");
 		gtk_label_set_label (GTK_LABEL (widget), title);
 	}
 
@@ -1315,9 +1365,9 @@ ch_flash_startup_cb (GApplication *application, ChFlashPrivate *priv)
 	/* get UI */
 	string = g_string_new ("");
 	priv->builder = gtk_builder_new ();
-	retval = gtk_builder_add_from_file (priv->builder,
-					    CH_DATA "/ch-flash.ui",
-					    &error);
+	retval = gtk_builder_add_from_resource (priv->builder,
+						"/com/hughski/colorhug/ch-flash.ui",
+						&error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s",
 			   error->message);
@@ -1340,6 +1390,9 @@ ch_flash_startup_cb (GApplication *application, ChFlashPrivate *priv)
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_close"));
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (ch_flash_close_button_cb), priv);
+	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_help"));
+	g_signal_connect (widget, "clicked",
+			  G_CALLBACK (ch_flash_help_button_cb), priv);
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_flash"));
 	g_signal_connect (widget, "clicked",
 			  G_CALLBACK (ch_flash_flash_button_cb), priv);
